@@ -1,6 +1,9 @@
-import sys, os
+import os
+import sys
+
 import sqlitedict
 
+
 def test():
     "Verify autocommit just before program exits."
     assert os.system('PYTHONPATH=. %s tests/autocommit.py' % sys.executable) == 0
